@@ -704,6 +704,38 @@ rsvg_characters_impl (RsvgHandle * ctx, const xmlChar * ch, int len)
     if (!ch || !len)
         return;
 
+	if (ctx->priv->currentnode)
+		{
+			if (!strcmp ("tspan", ctx->priv->currentnode->type->str) ||
+				!strcmp ("text", ctx->priv->currentnode->type->str))
+				{
+					guint i;
+
+					/* find the last CHARS node in the text or tspan node, so that we
+					   can coalesce the text, and thus avoid screwing up the Pango layouts */
+					self = NULL;
+					for (i = 0; i < ctx->priv->currentnode->children->len; i++) {
+						RsvgNode *node = g_ptr_array_index (ctx->priv->currentnode->children, i);
+						if (!strcmp (node->type->str, "RSVG_NODE_CHARS")) {
+							self = (RsvgNodeChars*)node;
+						}
+					}
+
+					if (self != NULL) {
+						if (!g_utf8_validate ((char *) ch, len, NULL)) {
+							char *utf8;
+							utf8 = rsvg_make_valid_utf8 ((char *) ch, len);
+							g_string_append (self->contents, utf8);
+							g_free (utf8);
+						} else {
+							g_string_append_len (self->contents, (char *)ch, len);
+						}
+
+						return;
+					}
+				}
+		}
+
     self = g_new (RsvgNodeChars, 1);
     _rsvg_node_init (&self->super);
 
@@ -1047,6 +1079,8 @@ rsvg_handle_close_impl (RsvgHandle * handle, GError ** error)
 {
     GError *real_error = NULL;
 
+	handle->priv->is_closed = TRUE;
+
     handle->priv->error = &real_error;
 
     if (handle->priv->ctxt != NULL) {
@@ -1484,6 +1518,7 @@ gboolean
 rsvg_handle_write (RsvgHandle * handle, const guchar * buf, gsize count, GError ** error)
 {
     rsvg_return_val_if_fail (handle, FALSE, error);
+    rsvg_return_val_if_fail (!handle->priv->is_closed, FALSE, error);
 
     if (handle->priv->first_write) {
         handle->priv->first_write = FALSE;
@@ -1527,6 +1562,9 @@ rsvg_handle_close (RsvgHandle * handle, GError ** error)
 {
     rsvg_return_val_if_fail (handle, FALSE, error);
 
+	if (handle->priv->is_closed)
+		return TRUE;
+
 #if HAVE_SVGZ
     if (handle->priv->is_gzipped) {
         GsfInput *gzip;
@@ -1592,10 +1630,6 @@ rsvg_init (void)
 #endif
 
     xmlInitParser ();
-
-#ifdef HAVE_GNOME_VFS
-    gnome_vfs_init ();
-#endif
 }
 
 /**
