@@ -60,6 +60,20 @@ typedef enum {
     UNICODE_BIDI_OVERRIDE = 2
 } UnicodeBidi;
 
+typedef enum {
+    SHAPE_RENDERING_AUTO = 0,
+    SHAPE_RENDERING_OPTIMIZE_SPEED,
+    SHAPE_RENDERING_CRISP_EDGES,
+    SHAPE_RENDERING_GEOMETRIC_PRECISION
+} ShapeRenderingProperty;
+
+typedef enum {
+    TEXT_RENDERING_AUTO = 0,
+    TEXT_RENDERING_OPTIMIZE_SPEED,
+    TEXT_RENDERING_OPTIMIZE_LEGIBILITY,
+    TEXT_RENDERING_GEOMETRIC_PRECISION
+} TextRenderingProperty;
+
 typedef enum {
     RSVG_COMP_OP_CLEAR,
     RSVG_COMP_OP_SRC,
@@ -187,6 +201,9 @@ struct _RsvgState {
     gboolean visible;
     gboolean has_visible;
 
+    gboolean space_preserve;
+    gboolean has_space_preserve;
+
     gboolean has_cond;
     gboolean cond_true;
 
@@ -211,6 +228,12 @@ struct _RsvgState {
 
     RsvgCompOpType comp_op;
     RsvgEnableBackgroundType enable_background;
+
+    ShapeRenderingProperty shape_rendering_type;
+    gboolean has_shape_rendering_type;
+    
+    TextRenderingProperty text_rendering_type;
+    gboolean has_text_rendering_type;
 };
 
 RsvgState *rsvg_state_new ();
